@@ -16,7 +16,7 @@ Usage::
     session_client: IdentityStoreClient = session.client("identitystore")
     ```
 """
-from mypy_boto3_identitystore.client import IdentityStoreClient
+from .client import IdentityStoreClient
 
 Client = IdentityStoreClient
 
